@@ -1,6 +1,6 @@
 ##########################################################################
 # Lilies
-# By: Matt Zychowski (copyright 2014-2019)
+# By: Matt Zychowski (copyright 2014-2021)
 #
 # A library wrapped around colorama for using colored strings in the terminal
 # window.  Provides advanced manipulation of colored strings, including
@@ -10,7 +10,6 @@
 
 from __future__ import print_function
 from builtins import str
-from builtins import input
 from . import grow, __version__
 
 
@@ -23,4 +22,3 @@ print("Author: Matt Zychowski")
 print()
 print("=" * 50)
 print()
-input("Press [ENTER] to run tests.")
