@@ -1,6 +1,6 @@
 from builtins import str
 from future.utils import string_types
-from .base import LilyBase
+from .objects.base import LilyBase
 
 
 def wilt(s):
