@@ -1,17 +1,24 @@
-from .detect import detect_terminal
+from .detect import detect_terminal, print_features
 from .nocolor import NoColorTerminal
 from .ansi8 import Ansi8Terminal
 from .ansi8open import Ansi8OpenTerminal
 from .aixterm import AixTerminal
 from .ansi16 import Ansi16Terminal
 from .ansi256 import Ansi256Terminal
+from .truecolor import TrueColorTerminal
+from .windows import WinTrueColor, WinLegacy, Win256Color
 
 __all__ = [
     "detect_terminal",
+    "print_features",
     "NoColorTerminal",
     "Ansi8Terminal",
     "Ansi8OpenTerminal",
     "AixTerminal",
     "Ansi16Terminal",
     "Ansi256Terminal",
+    "TrueColorTerminal",
+    "WinTrueColor",
+    "WinLegacy",
+    "Win256Color",
 ]
