@@ -2,7 +2,7 @@ from .win10mixin import Win10Mixin
 from .win32mixin import Win32Mixin
 from .truecolor import TrueColorTerminal
 from .ansi256 import Ansi256Terminal
-from .ansi16 import Ansi16Terminal
+from .aixterm import AixTerminal
 
 
 class WinTrueColor(Win10Mixin, TrueColorTerminal):
@@ -13,5 +13,5 @@ class Win256Color(Win10Mixin, Ansi256Terminal):
     pass
 
 
-class WinLegacy(Win32Mixin, Ansi16Terminal):
+class WinLegacy(Win32Mixin, AixTerminal):
     pass
